@@ -25,7 +25,7 @@ import pandas as pd
 
 """ Simple way to plot raster file """
 
-def show_fig(image, title=None, color='spectral', ctitle='colorbar title', bounds=None, res=None, vmin=None, vmax=None, savefig=False):
+def show_fig(image, title=None, color='Spectral', ctitle='colorbar title', bounds=None, res=None, vmin=None, vmax=None, savefig=False):
     fig, ax = plt.subplots(figsize=(12,6))
     c = ax.imshow(image, cmap=color, extent=bounds, vmin=vmin, vmax=vmax)
     if res != None:
@@ -59,8 +59,8 @@ def shpClip(geotiff, shapefile, destination, nan_val=0, fill=True, pad_size=0):
     with rasterio.open(geotiff) as src:
         # we need to make a temporary shapefile with the same crs as the geotiff 
         shpReprojection(shapefile, src.crs, dst='temp.shp')
-        with fiona.open('temp.shp', 'r') as shapefile:
-            shapes = [feature['geometry'] for feature in shapefile]
+        with fiona.open('temp.shp', 'r') as openshape:
+            shapes = [feature['geometry'] for feature in openshape]
 
         out_image, out_transform = rasterio.mask.mask(
             src, 
